@@ -1,6 +1,5 @@
-from typing import Any, List, Optional, Tuple, Type
 from dataclasses import dataclass, field
-
+from typing import Any, List, Type
 
 @dataclass
 class Error:
